==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/LastYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastYearExpressionDescription } from "./LastYearExpressionDescription";
/**
 * @hidden
 */
var LastYearExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LastYearExpressionDescriptionMetadata, _super);
    function LastYearExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastYearExpressionDescriptionMetadata.b = function (a) {
        if (LastYearExpressionDescriptionMetadata.a == null) {
            LastYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastYearExpressionDescriptionMetadata.c(LastYearExpressionDescriptionMetadata.a);
        }
        if (a.j(LastYearExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(LastYearExpressionDescriptionMetadata.a);
    };
    LastYearExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastYearExpressionDescriptionMetadata.d = function (a) {
        LastYearExpressionDescriptionMetadata.b(a);
        a.aa("LastYearExpression", function () { return new LastYearExpressionDescription(); });
        a.z("LastYearExpression", LastYearExpressionDescriptionMetadata.a);
    };
    LastYearExpressionDescriptionMetadata.$t = markType(LastYearExpressionDescriptionMetadata, 'LastYearExpressionDescriptionMetadata');
    LastYearExpressionDescriptionMetadata.a = null;
    return LastYearExpressionDescriptionMetadata;
}(Base));
export { LastYearExpressionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/LastYearExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastYearExpressionDescription } from "./LastYearExpressionDescription";
/**
 * @hidden
 */
var LastYearExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(LastYearExpressionDescriptionMetadata, _super);
    function LastYearExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastYearExpressionDescriptionMetadata.b = function (a) {
        if (LastYearExpressionDescriptionMetadata.a == null) {
            LastYearExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastYearExpressionDescriptionMetadata.c(LastYearExpressionDescriptionMetadata.a);
        }
        if (a.k(LastYearExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(LastYearExpressionDescriptionMetadata.a);
    };
    LastYearExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastYearExpressionDescriptionMetadata.d = function (a) {
        LastYearExpressionDescriptionMetadata.b(a);
        a.ac("LastYearExpression", function () { return new LastYearExpressionDescription(); });
        a.ab("LastYearExpression", LastYearExpressionDescriptionMetadata.a);
    };
    LastYearExpressionDescriptionMetadata.$t = markType(LastYearExpressionDescriptionMetadata, 'LastYearExpressionDescriptionMetadata');
    LastYearExpressionDescriptionMetadata.a = null;
    return LastYearExpressionDescriptionMetadata;
}(Base));
export { LastYearExpressionDescriptionMetadata };
